import os 
# dir_path = os.path.dirname(os.path.realpath(__file__))
import pydub 
from pydub import AudioSegment
from pydub.playback import play
cwd = os.getcwd()
 
from .loadingmodule import load_any


def playback_audio(cmnd):
    print ("Playing an audio file ")
    sound = load_any(cmnd)
    play(sound)
    
def pan(cmnd):
    print ("increasing volume")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    val = cmnd [2]
    song = AudioSegment.from_wav(input_name)
    vl= 0 - val
    panned_right = song.pan(+0.15)

    # pan the sound 50% to the left
    panned_left = song.pan(-0.50)
    
    # save the output
    song.export("leftpan.wav", "wav")


def get_max(cmnd):
    print ("getting max amplitude of an audio file ")
    sound = load_any(cmnd)
    peak_amplitude = sound.max
    print (peak_amplitude)

def repeat_audio(cmnd):
    print ("repeating audio file")
    output_name = "repeated.wav"
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print ("file 1")
    print(input_name)

    repeated_times = 2
    file_type ="wav"
    
    if ( len(cmnd) == 3 ):
        repeated_times = cmnd[2]
    
    if ( len(cmnd) == 4):
        tmp = cmnd[3]
        output_name = str(tmp)
        tmpf = output_name[-3:]
        file_type = str(tmpf)

    sound1 = AudioSegment.from_file(input_name, format="wav")
    # sound2 = AudioSegment.from_file(tf_name, format="wav")
    repeated = sound1 * repeated_times
    repeated.export("repeated.wav", "wav")
    
def slice_front(cmnd):
    print (" Slicing first section from the audio ")

    output_name = "firstslice.wav"
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    
    val=cmnd [2]
    
    file_type = "wav"
    if ( len(cmnd) == 4):
        
        tmp = cmnd[3]
        output_name = str(tmp)
        tmpf = output_name[-3:]
        file_type = str(tmpf)

    song = AudioSegment.from_wav(input_name)
    
    f_song = song[:val*1000]
    
    
    # save the output
    f_song.export(output_name, file_type)

def slice_back(cmnd):
    print (" Slicing back section from the audio ")
    output_name = "lastslice.wav"
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    val=cmnd [2]
    
    file_type = "wav"
    if ( len(cmnd) == 4):
        tmp = cmnd[3]
        output_name = str(tmp)
        tmpf = output_name[-3:]
        file_type = str(tmpf)

    song = AudioSegment.from_wav(input_name)
    
    b_song = song[val*1000:]
    
    # save the output
    b_song.export(output_name, file_type)
    
def slice_song(cmnd):
    print (" Slicing a section from the audio ")
    output_name =  "sliced.wav"
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)

    file_type = "wav"

    if ( len(cmnd) == 5):
        tmp = cmnd[4]
        output_name = str(tmp)
        tmpf = output_name[-3:]
        file_type = str(tmpf)

    val = cmnd [2]
    valt = cmnd [3]
    song = AudioSegment.from_wav(input_name)
    
    s_song = song[val*1000:valt*1000]
    
    
    # save the output
    s_song.export(output_name, file_type)

def file_reverse(cmnd):
    
    print ("reversing track")
    output_name =  "reversed.wav"
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    file_type = "wav"
    
    if ( len(cmnd) == 3):
        tmp = cmnd[2]
        output_name = str(tmp)
        tmpf = output_name[-3:]
        file_type = str(tmpf)

    song = AudioSegment.from_wav(input_name)
    
    backwards = song.reverse()

    # save the output
    backwards.export(output_name, file_type)

def posgain(cmnd):
    
    print ("increasing volume")
    output_name =  "higher.wav"
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    val = cmnd [2]
    file_type = "wav"

    if ( len(cmnd) == 4):
        tmp = cmnd[3]
        output_name = str(tmp)
        tmpf = output_name[-3:]
        file_type = str(tmpf)

    # song = AudioSegment.from_wav(input_name)
    song = load_any(cmnd)
    
    song = song + val

    # save the output
    song.export(output_name, file_type)


def negain(cmnd):
    
    print ("decreasing volume")
    output_name = "quiter.wav"
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    val = cmnd [2]
    file_type = "wav"
    
    if ( len(cmnd) == 4 ):
        tmp = cmnd[3]
        output_name = str(tmp)
        tmpf = output_name[-3:]
        file_type = str(tmpf)

    song = AudioSegment.from_wav(input_name)
    
    song = song - val

    # save the output
    song.export(output_name, file_type)


from glob import glob
from pydub import AudioSegment


from pydub.generators import WhiteNoise

from random import *

import math
import os 

from .resamplemodule import returnduration

from .loadingmodule import load_any

cwd = os.getcwd()

def write_script(cmnd):
    print (" Write the Commands following the block diagram instructions ")
    script_list = raw_input("Please abide to syntax ")

    print (script_list)

def normalize_audio(cmnd):
    print ("Normalizing audio file ")
    output_name = "normalized.wav"
    sound = load_any(cmnd)

    file_type = "wav"
    if ( len(cmnd) == 3):
        
        tmp = cmnd[2]
        output_name = str(tmp)
        tmpf = output_name[-3:]
        file_type = str(tmpf)

    normalized_sound = sound.apply_gain(-sound.max_dBFS)

    normalized_sound.export(output_name, file_type)

def fftnoise(f):
    f = np.array(f, dtype='complex')
    Np = (len(f) - 1) // 2
    phases = np.random.rand(Np) * 2 * np.pi
    phases = np.cos(phases) + 1j * np.sin(phases)
    f[1:Np+1] *= phases
    f[-1:-1-Np:-1] = np.conj(f[1:Np+1])
    return np.fft.ifft(f).real

def band_limited_noise(min_freq, max_freq, samples=1024, samplerate=1):
    freqs = np.abs(np.fft.fftfreq(samples, 1/samplerate))
    f = np.zeros(samples)
    idx = np.where(np.logical_and(freqs>=min_freq, freqs<=max_freq))[0]
    f[idx] = 1
    return fftnoise(f)

def generate_noise(cmnd):
    # get the 4 args from the command 
    x = band_limited_noise(200, 2000, 44100, 44100)
    y = np.int16(x * (2**15 - 1))
    y.export("noise.wav","wav")

def calc_pan(index):
    print ("getting song index")

    return cos(radians(index))

def dynamic_overlay(cmnd):
    #gets the largest file duration first and places it the first file in the over lay 
    print ("Overlaying  audio files")
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print ("file 1")
    print(input_name)
    tf = cmnd[2]
    tf_name= cwd +'/'+ tf
    print (tf_name)
    #determining the larger file 
    dur1 = returnduration(input_name)
    dur2 = returnduration(tf_name)
    
    sound1 = load_any(input_name)
    sound2 = load_any(tf_name)

    if( dur1 > dur2 ):
        combined = sound1.overlay(sound2)
    else:
        combined = sound2.overlay(sound1)
        
    combined.export("expertover.wav", format='wav')

def overlay_audio(cmnd):
    print ("Overlaying 2 audio files")
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print ("file 1")
    print(input_name)
    tf = cmnd[2]
    tf_name= cwd +'/'+ tf
    print (tf_name)
    sound1 = AudioSegment.from_file(input_name, format="wav")
    sound2 = AudioSegment.from_file(tf_name, format="wav")
    combined = sound1.overlay(sound2)

    combined.export("over.wav", format='wav')
    

def combine_audio(cmnd):
    
    print ("combining 2 audio file")
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print ("file 1")
    print(input_name)
    tf = cmnd[2]
    tf_name= cwd +'/'+ tf
    print (tf_name)
    sound1 = AudioSegment.from_file(input_name, format="wav")
    sound2 = AudioSegment.from_file(tf_name, format="wav")
    combined = sound1 + sound2
    combined.export("combined.wav", "wav")


def cross_fade(cmnd):
    
    print ("Cross fading")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    val = cmnd [2]
    
    song_duration = returnduration(input_name)
    song = AudioSegment.from_wav(input_name)
    
    first = song_duration - val
    
    end = song[val *-1000:]
    beginning = song[:first*1000]

    with_style = beginning.append(end, crossfade=val *1000)
    # save the output
    with_style.export("crossfaded.wav", "wav")

def fade_in(cmnd):
    print ("fading in")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    val = cmnd [2]
    song = AudioSegment.from_wav(input_name)
    awesome = song.fade_in(val)
    # save the output
    awesome.export("fadein.wav", "wav")

def fade_out(cmnd):
    print ("fading out")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    val = cmnd [2]
    song = load_any(cmnd)
    awesome = song.fade_out(val)
    # save the output
    awesome.export("fadeout.wav", "wav")

def eight(cmnd):

    #playlist_songs = [AudioSegment.from_mp3(mp3_file) for mp3_file in glob("mp3/*.mp3")]

    #first_song = playlist_songs.pop(0)
    interval = 0.2 * 1000  # sec

    song = AudioSegment.from_mp3('mp3/castle-of-glass.mp3')
    song_inverted = song.invert_phase()
    song.overlay(song_inverted)

    splitted_song = splitted_song_inverted = []
    song_start_point = 0

    print ("split song in part")
    while song_start_point + interval < len(song):
        splitted_song.append(song[song_start_point:song_start_point + interval])
        #splitted_song_inverted.append(song_inverted[song_start_point:song_start_point+interval])
        song_start_point += interval

    if song_start_point < len(song):
        splitted_song.append(song[song_start_point:])
        #splitted_song_inverted.append(song[song_start_point:])

    print ("end splitting")
    print ("total pieces: " + str(len(splitted_song)))

    ambisonics_song = splitted_song.pop(0)
    pan_index = 0
    #left_db_index = 45
    #right_db_index = 45
    index = 0
    for piece in splitted_song:
        print( "start panning pieces: " + str(index))
        pan_index += 5
        piece = piece.pan(calc_pan(pan_index))
        #WN = WhiteNoise().to_audio_segment(interval).apply_gain(-10.5).pan(-calc_pan(pan_index))
        #piece.overlay(splitted_song_inverted[index].pan(-calc_pan(pan_index)))
        ambisonics_song = ambisonics_song.append(piece, crossfade=interval / 50)
        index += 1
        #left_db_index = calc_left(left_db_index, right_db_index)
        #right_db_index = calc_right(right_db_index, left_db_index)

    # lets save it!
    out_f = open("compiled/castle-of-glass.mp3", 'wb')

    ambisonics_song.export(out_f, format='mp3')


import sys
import fire

from .classmodule import MyAudio
from .funcmodule import my_function

#loading methods

from .resamplemodule import getlength
from .resamplemodule import getsize
from .resamplemodule import getduration
from .resamplemodule import downsample
from .resamplemodule import getrate
from .resamplemodule import upsample


from .effectsmodule import file_reverse
from .effectsmodule import slice_back
from .effectsmodule import slice_song
from .effectsmodule import slice_front
from .effectsmodule import posgain
from .effectsmodule import negain
from .effectsmodule import repeat_audio
from .effectsmodule import playback_audio
from .effectsmodule import get_max

from .supereffectmodule import overlay_audio
from .supereffectmodule import normalize_audio
from .supereffectmodule import dynamic_overlay
from .supereffectmodule import combine_audio
from .supereffectmodule import calc_pan
from .supereffectmodule import write_script

from .loadingmodule import load_mp3
from .loadingmodule import load_wav
from .loadingmodule import load_any
from .loadingmodule import convert_all_mp3
from .loadingmodule import convert_all_wav
from .loadingmodule import change_bit_rate

version = "beta 1.0.0"
info = "A Python Command Line Interface (CLI) that performs Digital Audio Workstations (DAW) actions using Digital Signal Processing (DSP) Techinques and algorithms "
def main():

    args = sys.argv[1:]
    togller = True
    i = 0
    al = len(args)
    
    if(al == 0):
        print ("Welcome to Python CLI a tool to replace DAW using DSP ")
        togller =False
    
    if(al > 0):
        print('Welcome to GUC CLI ')
        print('count of args :: {}'.format(len(args)))
        a_string = args[0]
        first_letter = a_string[:1]
        
        # if( a_string == '-info'):
        #     fire.Fire(info)
        # elif( a_string == '-v'):
        #     fire.Fire(version)
        
    #filter arguments to know which method are we gonna use 
    while(i< al and (togller ==True)):
        
        arg= args[i]
        if( i==0 ):
            if(arg == "loadwav"):
                load_wav(args)
            elif (arg == "loadmp3"):
                load_mp3(args)
            elif (arg == "gain"):
                posgain(args)
            elif (arg == "negain"):
                negain(args)
            elif (arg == "upsample"):
                upsample(args)
            elif (arg == "getrate"):
                getrate(args)
            elif (arg == "downsample"):
                downsample(args)
            elif (arg == "getduration"):
                getduration(args)
            elif (arg == "getsize"):
                getsize(args)
            elif (arg == "getlength"):
                getlength(args)
            elif (arg == "reverse"):
                file_reverse(args)
            elif ( arg == "combine"):
                combine_audio(args)
            elif ( arg == "repeat"):
                repeat_audio(args)
            elif ( arg == "slice"):
                slice_song(args)
            elif ( arg == "overlay"):
                overlay_audio(args)
            elif ( arg == "expertoverlay"):
                dynamic_overlay(args)
            elif ( arg == "backslice"):
                slice_back(args)
            elif ( arg == "normalize"):
                normalize_audio(args)
            elif ( arg == "play"):
                playback_audio(args)
            elif ( arg == "wavconvert"):
                convert_all_wav(args)
            elif ( arg == "mp3convert"):
                convert_all_mp3(args)
            elif( arg == "cbr" ):
                change_bit_rate(args)
            elif ( arg == "getmax" ):
                get_max(args)
            elif (arg == "script" ):
                write_script(args)
            else:
                print ("Command is not found or incorrect please try again ")
        print('input argument :: {}'.format(arg))
        i = i+1
    my_function('Operations complete ')
    
    # my_object = MyAudio('Input.mp3')
    # my_object.say_name()

if __name__ == '__main__':
    # main()
    fire.Fire()


import os 
# dir_path = os.path.dirname(os.path.realpath(__file__))
import pydub 
from pydub import AudioSegment
from .loadingmodule import load_any
cwd = os.getcwd()
import wave
import contextlib



def upsample(cmnd):
    print ("upsampling to 48000 Hz")
    print(cwd)
    text_to_file = cmnd[1]
    
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    # # initialize portaudio
    # p = pyaudio.PyAudio()
    # stream = p.open(format=pyaudio.paInt16, channels=1, rate=48000, input=True, frames_per_buffer=CHUNKSIZE)

    # # do this as long as you want fretsh samples
    # data = stream.read(CHUNKSIZE)
    # numpydata = np.fromstring(data, dtype=np.int16)

    # close stream
    # stream.stop_stream()
    # stream.close()
    # p.terminate()
    CHANNELS = 2
    swidth = 2
    spf = wave.open(input_name, 'rb')
    RATE=spf.getframerate()
    print( " Current frame rate is ")
    print(RATE)
    signal = spf.readframes(-1)
    if (RATE == 48000):
        return
    else:
        wf = wave.open('changed.wav', 'wb')
        wf.setnchannels(CHANNELS)
        wf.setsampwidth(swidth)
        Change_RATE = 1 + (1- RATE / 48000 )
        wf.setframerate(RATE*Change_RATE)
        wf.writeframes(signal)
        wf.close()

def getrate(cmnd):
    
    print ("Getting frame rate")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
  
    CHANNELS = 2
    spf = wave.open(input_name, 'rb')
    RATE=spf.getframerate()
    print (" Current frame rate is ")
    print(RATE)


#depreceated intentionally left to compare with get length as get length is more general
def getduration(cmnd):
    print ("The file duration of")
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    # CHANNELS = 2
    # spf = wave.open(input_name, 'rb')
    # RATE=spf.getframerate()
    # file_size =os.path.getsize(input_name)
    # # time = FileLength / (Sample Rate * Channels * Bits per sample /8)
    # time = file_size / (RATE * CHANNELS * 2)
    # print(time)
    with contextlib.closing(wave.open(input_name,'r')) as f:
        frames = f.getnframes()
        rate = f.getframerate()
        duration = frames / float(rate)
        print(duration)

def returnduration(input_name):
    
    print(input_name)
   
    with contextlib.closing(wave.open(input_name,'r')) as f:
        frames = f.getnframes()
        rate = f.getframerate()
        duration = frames / float(rate)
        print(duration)
        return duration
    return -1

def getsize(cmnd):
    print ("The file size of")
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    file_size =os.path.getsize(input_name)
    # + 0.0 to make size a float number
    siz = file_size + 0.0
    cu = 0
    while(siz > 1024):
        siz= siz/1024
        cu = cu + 1
    if(cu == 1):
        print (siz , " KB")
    elif(cu ==2):
        print (siz , " MB")
    elif(cu ==3):
        print (siz , " GB")

def getlength(cmnd):
    print ("The track length")
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    
    sound1 = load_any(cmnd)
    duration_in_milliseconds = len(sound1)
    millis = duration_in_milliseconds
    seconds=(millis/1000)%60
    seconds = int(seconds)
    minutes=(millis/(1000*60))%60
    minutes = int(minutes)
    hours=(millis/(1000*60*60))%24
    
    print ("%d:%d:%d" % (hours, minutes, seconds))

def downsample(cmnd):
    
    print ("upsampling to 8000 Hz")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    # initialize portaudio
    CHANNELS = 2
    swidth = 2
    spf = wave.open(input_name, 'rb')
    RATE=spf.getframerate()
    print( " Current frame rate is ")
    print(RATE)
    signal = spf.readframes(-1)
    if (RATE == 8000):
        return
    else:
        wf = wave.open('downsample.wav', 'wb')
        wf.setnchannels(CHANNELS)
        wf.setsampwidth(swidth)
        Change_RATE = 0.0
        Change_RATE = ( 8000.0 / RATE ) 
        print ("The change rate", Change_RATE)
        wf.setframerate(RATE*Change_RATE)
        wf.writeframes(signal)
        wf.close()





#module for generating sound 
import numpy as np
def generate_sample(freq,amp,duration,phi):
    NTONES =82
    amplitude = 2000 * np.random.random((NTONES,)) + 200
    # duration = 0.19 * np.random.random((NTONES,)) + 0.01
    keys = np.random.random_integers(1,88,NTONES)
    freqs = 440.0 *2**((keys-49)/12)

    # phi = 2 * np.pi * np.random.random((NTONES,))
    RATE = 2
    t = np.linspace(0,duration,duration *RATE)
    data = np.sin(2 * np.pi *freq *t +phi) *amp
    return data.astype(DTYPE)

def dasgenerate():
    for i inxrange(NTONES):
        newtone = generate_sample(freqs[i])


from setuptools import setup
with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name = 'pydaw',
    version = '1.0.1',
    author="Peter Hassaballah",
    author_email="peter.hassaballah@gmail.com",
    description="A Python CLI",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/peterHassaballah/pythoncli",
    install_requires=['fire==0.1.3','pydub==0.23.1'],
    packages = ['pythoncli'],
    entry_points = {
        'console_scripts': [
            'pythoncli = pythoncli.__main__:main'
        ]
    })


import os 
# dir_path = os.path.dirname(os.path.realpath(__file__))
import pydub 
import glob
from pydub import AudioSegment
# import pyaudio
# import numpy as np
cwd = os.getcwd()



def convert_all_mp3(cmnd):
    video_dir = cwd
    extension_list = ('*.mp4', '*.flv')
    os.chdir(video_dir)
    for extension in extension_list:
        for video in glob.glob(extension):
            mp3_filename = os.path.splitext(os.path.basename(video))[0] + '.mp3'
            AudioSegment.from_file(video).export(mp3_filename, format='mp3')

def convert_all_wav(cmnd):
    video_dir = cwd
    extension_list = ('*.mp4', '*.flv')
    os.chdir(video_dir)
    for extension in extension_list:
        for video in glob.glob(extension):
            wav_filename = os.path.splitext(os.path.basename(video))[0] + '.wav'
            AudioSegment.from_file(video).export(wav_filename, format='wav')
    
def load_any(cmnd):
    
    print ("Loading file and converting it to wav ")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    file_type = input_name[-3:]
    print(file_type)
    version = AudioSegment.from_file(input_name, str(file_type) )
    print("The returned type",type(version))
    return version
    # version.export("temporary.wav",format="wav")
    #remember to delete file after operation is called
    #os.remove(cwd +'/temporary.wav')
    # send flag to all functions whether to perform a delete or not 

def load_txt(cmnd, counter):
    print ("Loading file and converting it to wav ")
    print(cwd)
    #text file name
    text_file = cmnd[1]
    i_file=open(text_file,'r')
    for i in range(6):
        i_file.readline() 
        items=i_file.readline().split()
    #input name deducted from file
    input_name= items[counter]
    print(input_name)
    file_type = input_name[-3:]
    print(file_type)
    version = AudioSegment.from_file(input_name, str(file_type) )
    print("The returned type",type(version))
    return version


def change_bit_rate(cmnd):
    print ("Loading file and converting it to wav ")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    file_type = input_name[-3:]
    val = cmnd [2]
    version = AudioSegment.from_file(input_name, file_type)
    version.export('bitrate'+'.'+file_type,format=file_type , bitrate= val+'k')

def export_with_tags(cmnd):
    print ("Loading file")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    sound = AudioSegment.from_mp3(input_name)
    sound.export("mashup.mp3", format="mp3", tags={'artist': 'Various artists', 'album': 'Best of 2011', 'comments': 'This album is awesome!'})

def load_wav(cmnd):
    print ("Loading wave") 
    print(cwd)
    text_to_file = cmnd[1]
    
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    # initialize portaudio
    # p = pyaudio.PyAudio()
    # stream = p.open(format=pyaudio.paInt16, channels=1, rate=44100, input=True, frames_per_buffer=CHUNKSIZE)

    # # do this as long as you want fretsh samples
    # data = stream.read(CHUNKSIZE)
    # numpydata = np.fromstring(data, dtype=np.int16)


    # # close stream
    # stream.stop_stream()
    # stream.close()
    # p.terminate()
    sound = AudioSegment.from_mp3(input_name)
    sound.export(cwd+"/file.wav", format="wav")

def load_mp3(cmnd):
    print ("Loading mp3")
    print(cwd)
    text_to_file = cmnd[1]
    input_name= cwd +'/'+ text_to_file
    print(input_name)
    
    sound = AudioSegment.from_wav(input_name)
    sound.export(cwd+"/outputfile.mp3", format="mp3")